# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/prediction/v1/prediction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/prediction/v1/prediction.proto\x12\x34github.com.metaprov.modelaapi.services.prediction.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xfd\x01\n\x16ListPredictionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x02 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x01\n\x17ListPredictionsResponse\x12^\n\x0bpredictions\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictionList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1a\n\x18\x43reatePredictionResponse\"t\n\x17\x43reatePredictionRequest\x12Y\n\nprediction\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"\xa4\x01\n\x17UpdatePredictionRequest\x12Y\n\nprediction\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1a\n\x18UpdatePredictionResponse\"7\n\x14GetPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x80\x01\n\x15GetPredictionResponse\x12Y\n\nprediction\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65letePredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65letePredictionResponse\"<\n\x19\x44ownloadPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\")\n\x1a\x44ownloadPredictionResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\"9\n\x16\x41\x62ortPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x19\n\x17\x41\x62ortPredictionResponse2\xb9\x0c\n\x11PredictionService\x12\xd3\x01\n\x0fListPredictions\x12L.github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest\x1aM.github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/predictions/{namespace}\x12\xcd\x01\n\x10\x43reatePrediction\x12M.github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionRequest\x1aN.github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/predictions:\x01*\x12\xd4\x01\n\rGetPrediction\x12J.github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionRequest\x1aK.github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/predictions/{namespace}/{name}\x12\x88\x02\n\x10UpdatePrediction\x12M.github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionRequest\x1aN.github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/predictions/{prediction.metadata.namespace}/{prediction.metadata.name}:\x01*\x12\xdd\x01\n\x10\x44\x65letePrediction\x12M.github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionRequest\x1aN.github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/predictions/{namespace}/{name}\x12\xe2\x01\n\x08\x44ownload\x12O.github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionRequest\x1aP.github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionResponse\"3\x82\xd3\xe4\x93\x02-\x12+/v1/predictions/{namespace}/{name}:download\x12\xd6\x01\n\x05\x41\x62ort\x12L.github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionRequest\x1aM.github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionResponse\"0\x82\xd3\xe4\x93\x02*\"(/v1/predictions/{namespace}/{name}:abortB6Z4github.com/metaprov/modelaapi/services/prediction/v1b\x06proto3')



_LISTPREDICTIONSREQUEST = DESCRIPTOR.message_types_by_name['ListPredictionsRequest']
_LISTPREDICTIONSREQUEST_LABELSENTRY = _LISTPREDICTIONSREQUEST.nested_types_by_name['LabelsEntry']
_LISTPREDICTIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListPredictionsResponse']
_CREATEPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['CreatePredictionResponse']
_CREATEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['CreatePredictionRequest']
_UPDATEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdatePredictionRequest']
_UPDATEPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['UpdatePredictionResponse']
_GETPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['GetPredictionRequest']
_GETPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['GetPredictionResponse']
_DELETEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['DeletePredictionRequest']
_DELETEPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['DeletePredictionResponse']
_DOWNLOADPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['DownloadPredictionRequest']
_DOWNLOADPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['DownloadPredictionResponse']
_ABORTPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['AbortPredictionRequest']
_ABORTPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['AbortPredictionResponse']
ListPredictionsRequest = _reflection.GeneratedProtocolMessageType('ListPredictionsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPREDICTIONSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPREDICTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest)
  })
_sym_db.RegisterMessage(ListPredictionsRequest)
_sym_db.RegisterMessage(ListPredictionsRequest.LabelsEntry)

ListPredictionsResponse = _reflection.GeneratedProtocolMessageType('ListPredictionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsResponse)
  })
_sym_db.RegisterMessage(ListPredictionsResponse)

CreatePredictionResponse = _reflection.GeneratedProtocolMessageType('CreatePredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionResponse)
  })
_sym_db.RegisterMessage(CreatePredictionResponse)

CreatePredictionRequest = _reflection.GeneratedProtocolMessageType('CreatePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionRequest)
  })
_sym_db.RegisterMessage(CreatePredictionRequest)

UpdatePredictionRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionRequest)
  })
_sym_db.RegisterMessage(UpdatePredictionRequest)

UpdatePredictionResponse = _reflection.GeneratedProtocolMessageType('UpdatePredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionResponse)
  })
_sym_db.RegisterMessage(UpdatePredictionResponse)

GetPredictionRequest = _reflection.GeneratedProtocolMessageType('GetPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionRequest)
  })
_sym_db.RegisterMessage(GetPredictionRequest)

GetPredictionResponse = _reflection.GeneratedProtocolMessageType('GetPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionResponse)
  })
_sym_db.RegisterMessage(GetPredictionResponse)

DeletePredictionRequest = _reflection.GeneratedProtocolMessageType('DeletePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionRequest)
  })
_sym_db.RegisterMessage(DeletePredictionRequest)

DeletePredictionResponse = _reflection.GeneratedProtocolMessageType('DeletePredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionResponse)
  })
_sym_db.RegisterMessage(DeletePredictionResponse)

DownloadPredictionRequest = _reflection.GeneratedProtocolMessageType('DownloadPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionRequest)
  })
_sym_db.RegisterMessage(DownloadPredictionRequest)

DownloadPredictionResponse = _reflection.GeneratedProtocolMessageType('DownloadPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionResponse)
  })
_sym_db.RegisterMessage(DownloadPredictionResponse)

AbortPredictionRequest = _reflection.GeneratedProtocolMessageType('AbortPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionRequest)
  })
_sym_db.RegisterMessage(AbortPredictionRequest)

AbortPredictionResponse = _reflection.GeneratedProtocolMessageType('AbortPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionResponse)
  })
_sym_db.RegisterMessage(AbortPredictionResponse)

_PREDICTIONSERVICE = DESCRIPTOR.services_by_name['PredictionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/prediction/v1'
  _LISTPREDICTIONSREQUEST_LABELSENTRY._options = None
  _LISTPREDICTIONSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _PREDICTIONSERVICE.methods_by_name['ListPredictions']._options = None
  _PREDICTIONSERVICE.methods_by_name['ListPredictions']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/predictions/{namespace}'
  _PREDICTIONSERVICE.methods_by_name['CreatePrediction']._options = None
  _PREDICTIONSERVICE.methods_by_name['CreatePrediction']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/predictions:\001*'
  _PREDICTIONSERVICE.methods_by_name['GetPrediction']._options = None
  _PREDICTIONSERVICE.methods_by_name['GetPrediction']._serialized_options = b'\202\323\344\223\002$\022\"/v1/predictions/{namespace}/{name}'
  _PREDICTIONSERVICE.methods_by_name['UpdatePrediction']._options = None
  _PREDICTIONSERVICE.methods_by_name['UpdatePrediction']._serialized_options = b'\202\323\344\223\002O\032J/v1/predictions/{prediction.metadata.namespace}/{prediction.metadata.name}:\001*'
  _PREDICTIONSERVICE.methods_by_name['DeletePrediction']._options = None
  _PREDICTIONSERVICE.methods_by_name['DeletePrediction']._serialized_options = b'\202\323\344\223\002$*\"/v1/predictions/{namespace}/{name}'
  _PREDICTIONSERVICE.methods_by_name['Download']._options = None
  _PREDICTIONSERVICE.methods_by_name['Download']._serialized_options = b'\202\323\344\223\002-\022+/v1/predictions/{namespace}/{name}:download'
  _PREDICTIONSERVICE.methods_by_name['Abort']._options = None
  _PREDICTIONSERVICE.methods_by_name['Abort']._serialized_options = b'\202\323\344\223\002*\"(/v1/predictions/{namespace}/{name}:abort'
  _LISTPREDICTIONSREQUEST._serialized_start=267
  _LISTPREDICTIONSREQUEST._serialized_end=520
  _LISTPREDICTIONSREQUEST_LABELSENTRY._serialized_start=475
  _LISTPREDICTIONSREQUEST_LABELSENTRY._serialized_end=520
  _LISTPREDICTIONSRESPONSE._serialized_start=523
  _LISTPREDICTIONSRESPONSE._serialized_end=669
  _CREATEPREDICTIONRESPONSE._serialized_start=671
  _CREATEPREDICTIONRESPONSE._serialized_end=697
  _CREATEPREDICTIONREQUEST._serialized_start=699
  _CREATEPREDICTIONREQUEST._serialized_end=815
  _UPDATEPREDICTIONREQUEST._serialized_start=818
  _UPDATEPREDICTIONREQUEST._serialized_end=982
  _UPDATEPREDICTIONRESPONSE._serialized_start=984
  _UPDATEPREDICTIONRESPONSE._serialized_end=1010
  _GETPREDICTIONREQUEST._serialized_start=1012
  _GETPREDICTIONREQUEST._serialized_end=1067
  _GETPREDICTIONRESPONSE._serialized_start=1070
  _GETPREDICTIONRESPONSE._serialized_end=1198
  _DELETEPREDICTIONREQUEST._serialized_start=1200
  _DELETEPREDICTIONREQUEST._serialized_end=1258
  _DELETEPREDICTIONRESPONSE._serialized_start=1260
  _DELETEPREDICTIONRESPONSE._serialized_end=1286
  _DOWNLOADPREDICTIONREQUEST._serialized_start=1288
  _DOWNLOADPREDICTIONREQUEST._serialized_end=1348
  _DOWNLOADPREDICTIONRESPONSE._serialized_start=1350
  _DOWNLOADPREDICTIONRESPONSE._serialized_end=1391
  _ABORTPREDICTIONREQUEST._serialized_start=1393
  _ABORTPREDICTIONREQUEST._serialized_end=1450
  _ABORTPREDICTIONRESPONSE._serialized_start=1452
  _ABORTPREDICTIONRESPONSE._serialized_end=1477
  _PREDICTIONSERVICE._serialized_start=1480
  _PREDICTIONSERVICE._serialized_end=3073
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelasystem/v1/modelasystem.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIgithub.com/metaprov/modelaapi/services/modelasystem/v1/modelasystem.proto\x12\x36github.com.metaprov.modelaapi.services.modelasystem.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a google/protobuf/field_mask.proto\"\xca\x01\n\x18ListModelaSystemsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12l\n\x06labels\x18\x02 \x03(\x0b\x32\\.github.com.metaprov.modelaapi.services.modelasystem.v1.ListModelaSystemsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x19ListModelaSystemsResponse\x12^\n\rmodelasystems\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ModelaSystemList\"\x16\n\x14ModelaSystemResponse\"\x88\x01\n\x19\x43reateModelaSystemRequest\x12Y\n\x0cmodelasystem\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ModelaSystem\x12\x10\n\x08password\x18\x02 \x01(\t\"\x1c\n\x1a\x43reateModelaSystemResponse\"\xa6\x01\n\x19UpdateModelaSystemRequest\x12Y\n\x0cmodelasystem\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ModelaSystem\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1c\n\x1aUpdateModelaSystemResponse\"9\n\x16GetModelaSystemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x82\x01\n\x17GetModelaSystemResponse\x12Y\n\x0cmodelasystem\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ModelaSystem\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"C\n GetModelaSystemNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"x\n!GetModelaSystemNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"<\n\x19\x44\x65leteModelaSystemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1a\x44\x65leteModelaSystemResponse\"\x1c\n\x1aModelaSystemCreateResponse\"\x10\n\x0eLogoutResponse\"\x17\n\x15ResetPasswordResponse\"?\n\x1cModelaSystemGetByNameRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"*\n\x19ModelaSystemLogoutRequest\x12\r\n\x05token\x18\x01 \x01(\t\"I\n\x16\x44ownloadLogFileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\")\n\x17\x44ownloadLogFileResponse\x12\x0e\n\x06result\x18\x01 \x01(\x0c\"H\n\x15\x42\x61\x63kupDatabaseRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\"&\n\x16\x42\x61\x63kupDatabaseResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\"D\n\x11\x42\x61\x63kupEtcdRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\"\"\n\x12\x42\x61\x63kupEtcdResponse\x12\x0c\n\x04path\x18\x01 \x01(\t2\xb2\x0e\n\x13ModelaSystemService\x12\xdf\x01\n\x11ListModelaSystems\x12P.github.com.metaprov.modelaapi.services.modelasystem.v1.ListModelaSystemsRequest\x1aQ.github.com.metaprov.modelaapi.services.modelasystem.v1.ListModelaSystemsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/modelasystems/{namespace}\x12\xd9\x01\n\x12\x43reateModelaSystem\x12Q.github.com.metaprov.modelaapi.services.modelasystem.v1.CreateModelaSystemRequest\x1aR.github.com.metaprov.modelaapi.services.modelasystem.v1.CreateModelaSystemResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/modelasystems:\x01*\x12\xe0\x01\n\x0fGetModelaSystem\x12N.github.com.metaprov.modelaapi.services.modelasystem.v1.GetModelaSystemRequest\x1aO.github.com.metaprov.modelaapi.services.modelasystem.v1.GetModelaSystemResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/modelasystems/{namespace}/{name}\x12\x98\x02\n\x12UpdateModelaSystem\x12Q.github.com.metaprov.modelaapi.services.modelasystem.v1.UpdateModelaSystemRequest\x1aR.github.com.metaprov.modelaapi.services.modelasystem.v1.UpdateModelaSystemResponse\"[\x82\xd3\xe4\x93\x02U\x1aP/v1/modelasystems/{modelasystem.metadata.namespace}/{modelasystem.metadata.name}:\x01*\x12\xe9\x01\n\x12\x44\x65leteModelaSystem\x12Q.github.com.metaprov.modelaapi.services.modelasystem.v1.DeleteModelaSystemRequest\x1aR.github.com.metaprov.modelaapi.services.modelasystem.v1.DeleteModelaSystemResponse\",\x82\xd3\xe4\x93\x02&*$/v1/modelasystems/{namespace}/{name}\x12\xd4\x01\n\x0f\x44ownloadLogfile\x12N.github.com.metaprov.modelaapi.services.modelasystem.v1.DownloadLogFileRequest\x1aO.github.com.metaprov.modelaapi.services.modelasystem.v1.DownloadLogFileResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/download/{namespace}\x12\xd1\x01\n\x0e\x42\x61\x63kupDatabase\x12M.github.com.metaprov.modelaapi.services.modelasystem.v1.BackupDatabaseRequest\x1aN.github.com.metaprov.modelaapi.services.modelasystem.v1.BackupDatabaseResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x18/v1/backupdb/{namespace}\x12\xc7\x01\n\nBackupEtcd\x12I.github.com.metaprov.modelaapi.services.modelasystem.v1.BackupEtcdRequest\x1aJ.github.com.metaprov.modelaapi.services.modelasystem.v1.BackupEtcdResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/v1/backupetcd/{namespace}B8Z6github.com/metaprov/modelaapi/services/modelasystem/v1b\x06proto3')



_LISTMODELASYSTEMSREQUEST = DESCRIPTOR.message_types_by_name['ListModelaSystemsRequest']
_LISTMODELASYSTEMSREQUEST_LABELSENTRY = _LISTMODELASYSTEMSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELASYSTEMSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelaSystemsResponse']
_MODELASYSTEMRESPONSE = DESCRIPTOR.message_types_by_name['ModelaSystemResponse']
_CREATEMODELASYSTEMREQUEST = DESCRIPTOR.message_types_by_name['CreateModelaSystemRequest']
_CREATEMODELASYSTEMRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelaSystemResponse']
_UPDATEMODELASYSTEMREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelaSystemRequest']
_UPDATEMODELASYSTEMRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelaSystemResponse']
_GETMODELASYSTEMREQUEST = DESCRIPTOR.message_types_by_name['GetModelaSystemRequest']
_GETMODELASYSTEMRESPONSE = DESCRIPTOR.message_types_by_name['GetModelaSystemResponse']
_GETMODELASYSTEMNAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['GetModelaSystemNamespacesRequest']
_GETMODELASYSTEMNAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['GetModelaSystemNamespacesResponse']
_DELETEMODELASYSTEMREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelaSystemRequest']
_DELETEMODELASYSTEMRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelaSystemResponse']
_MODELASYSTEMCREATERESPONSE = DESCRIPTOR.message_types_by_name['ModelaSystemCreateResponse']
_LOGOUTRESPONSE = DESCRIPTOR.message_types_by_name['LogoutResponse']
_RESETPASSWORDRESPONSE = DESCRIPTOR.message_types_by_name['ResetPasswordResponse']
_MODELASYSTEMGETBYNAMEREQUEST = DESCRIPTOR.message_types_by_name['ModelaSystemGetByNameRequest']
_MODELASYSTEMLOGOUTREQUEST = DESCRIPTOR.message_types_by_name['ModelaSystemLogoutRequest']
_DOWNLOADLOGFILEREQUEST = DESCRIPTOR.message_types_by_name['DownloadLogFileRequest']
_DOWNLOADLOGFILERESPONSE = DESCRIPTOR.message_types_by_name['DownloadLogFileResponse']
_BACKUPDATABASEREQUEST = DESCRIPTOR.message_types_by_name['BackupDatabaseRequest']
_BACKUPDATABASERESPONSE = DESCRIPTOR.message_types_by_name['BackupDatabaseResponse']
_BACKUPETCDREQUEST = DESCRIPTOR.message_types_by_name['BackupEtcdRequest']
_BACKUPETCDRESPONSE = DESCRIPTOR.message_types_by_name['BackupEtcdResponse']
ListModelaSystemsRequest = _reflection.GeneratedProtocolMessageType('ListModelaSystemsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELASYSTEMSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ListModelaSystemsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELASYSTEMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ListModelaSystemsRequest)
  })
_sym_db.RegisterMessage(ListModelaSystemsRequest)
_sym_db.RegisterMessage(ListModelaSystemsRequest.LabelsEntry)

ListModelaSystemsResponse = _reflection.GeneratedProtocolMessageType('ListModelaSystemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELASYSTEMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ListModelaSystemsResponse)
  })
_sym_db.RegisterMessage(ListModelaSystemsResponse)

ModelaSystemResponse = _reflection.GeneratedProtocolMessageType('ModelaSystemResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELASYSTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemResponse)
  })
_sym_db.RegisterMessage(ModelaSystemResponse)

CreateModelaSystemRequest = _reflection.GeneratedProtocolMessageType('CreateModelaSystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELASYSTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.CreateModelaSystemRequest)
  })
_sym_db.RegisterMessage(CreateModelaSystemRequest)

CreateModelaSystemResponse = _reflection.GeneratedProtocolMessageType('CreateModelaSystemResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELASYSTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.CreateModelaSystemResponse)
  })
_sym_db.RegisterMessage(CreateModelaSystemResponse)

UpdateModelaSystemRequest = _reflection.GeneratedProtocolMessageType('UpdateModelaSystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELASYSTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.UpdateModelaSystemRequest)
  })
_sym_db.RegisterMessage(UpdateModelaSystemRequest)

UpdateModelaSystemResponse = _reflection.GeneratedProtocolMessageType('UpdateModelaSystemResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELASYSTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.UpdateModelaSystemResponse)
  })
_sym_db.RegisterMessage(UpdateModelaSystemResponse)

GetModelaSystemRequest = _reflection.GeneratedProtocolMessageType('GetModelaSystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELASYSTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.GetModelaSystemRequest)
  })
_sym_db.RegisterMessage(GetModelaSystemRequest)

GetModelaSystemResponse = _reflection.GeneratedProtocolMessageType('GetModelaSystemResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELASYSTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.GetModelaSystemResponse)
  })
_sym_db.RegisterMessage(GetModelaSystemResponse)

GetModelaSystemNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetModelaSystemNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELASYSTEMNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.GetModelaSystemNamespacesRequest)
  })
_sym_db.RegisterMessage(GetModelaSystemNamespacesRequest)

GetModelaSystemNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetModelaSystemNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELASYSTEMNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.GetModelaSystemNamespacesResponse)
  })
_sym_db.RegisterMessage(GetModelaSystemNamespacesResponse)

DeleteModelaSystemRequest = _reflection.GeneratedProtocolMessageType('DeleteModelaSystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELASYSTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.DeleteModelaSystemRequest)
  })
_sym_db.RegisterMessage(DeleteModelaSystemRequest)

DeleteModelaSystemResponse = _reflection.GeneratedProtocolMessageType('DeleteModelaSystemResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELASYSTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.DeleteModelaSystemResponse)
  })
_sym_db.RegisterMessage(DeleteModelaSystemResponse)

ModelaSystemCreateResponse = _reflection.GeneratedProtocolMessageType('ModelaSystemCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELASYSTEMCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemCreateResponse)
  })
_sym_db.RegisterMessage(ModelaSystemCreateResponse)

LogoutResponse = _reflection.GeneratedProtocolMessageType('LogoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.LogoutResponse)
  })
_sym_db.RegisterMessage(LogoutResponse)

ResetPasswordResponse = _reflection.GeneratedProtocolMessageType('ResetPasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ResetPasswordResponse)
  })
_sym_db.RegisterMessage(ResetPasswordResponse)

ModelaSystemGetByNameRequest = _reflection.GeneratedProtocolMessageType('ModelaSystemGetByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODELASYSTEMGETBYNAMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemGetByNameRequest)
  })
_sym_db.RegisterMessage(ModelaSystemGetByNameRequest)

ModelaSystemLogoutRequest = _reflection.GeneratedProtocolMessageType('ModelaSystemLogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODELASYSTEMLOGOUTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemLogoutRequest)
  })
_sym_db.RegisterMessage(ModelaSystemLogoutRequest)

DownloadLogFileRequest = _reflection.GeneratedProtocolMessageType('DownloadLogFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADLOGFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.DownloadLogFileRequest)
  })
_sym_db.RegisterMessage(DownloadLogFileRequest)

DownloadLogFileResponse = _reflection.GeneratedProtocolMessageType('DownloadLogFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADLOGFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.DownloadLogFileResponse)
  })
_sym_db.RegisterMessage(DownloadLogFileResponse)

BackupDatabaseRequest = _reflection.GeneratedProtocolMessageType('BackupDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPDATABASEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.BackupDatabaseRequest)
  })
_sym_db.RegisterMessage(BackupDatabaseRequest)

BackupDatabaseResponse = _reflection.GeneratedProtocolMessageType('BackupDatabaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPDATABASERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.BackupDatabaseResponse)
  })
_sym_db.RegisterMessage(BackupDatabaseResponse)

BackupEtcdRequest = _reflection.GeneratedProtocolMessageType('BackupEtcdRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPETCDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.BackupEtcdRequest)
  })
_sym_db.RegisterMessage(BackupEtcdRequest)

BackupEtcdResponse = _reflection.GeneratedProtocolMessageType('BackupEtcdResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPETCDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.BackupEtcdResponse)
  })
_sym_db.RegisterMessage(BackupEtcdResponse)

_MODELASYSTEMSERVICE = DESCRIPTOR.services_by_name['ModelaSystemService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/metaprov/modelaapi/services/modelasystem/v1'
  _LISTMODELASYSTEMSREQUEST_LABELSENTRY._options = None
  _LISTMODELASYSTEMSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELASYSTEMSERVICE.methods_by_name['ListModelaSystems']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['ListModelaSystems']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/modelasystems/{namespace}'
  _MODELASYSTEMSERVICE.methods_by_name['CreateModelaSystem']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['CreateModelaSystem']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/modelasystems:\001*'
  _MODELASYSTEMSERVICE.methods_by_name['GetModelaSystem']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['GetModelaSystem']._serialized_options = b'\202\323\344\223\002&\022$/v1/modelasystems/{namespace}/{name}'
  _MODELASYSTEMSERVICE.methods_by_name['UpdateModelaSystem']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['UpdateModelaSystem']._serialized_options = b'\202\323\344\223\002U\032P/v1/modelasystems/{modelasystem.metadata.namespace}/{modelasystem.metadata.name}:\001*'
  _MODELASYSTEMSERVICE.methods_by_name['DeleteModelaSystem']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['DeleteModelaSystem']._serialized_options = b'\202\323\344\223\002&*$/v1/modelasystems/{namespace}/{name}'
  _MODELASYSTEMSERVICE.methods_by_name['DownloadLogfile']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['DownloadLogfile']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/download/{namespace}'
  _MODELASYSTEMSERVICE.methods_by_name['BackupDatabase']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['BackupDatabase']._serialized_options = b'\202\323\344\223\002\032\"\030/v1/backupdb/{namespace}'
  _MODELASYSTEMSERVICE.methods_by_name['BackupEtcd']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['BackupEtcd']._serialized_options = b'\202\323\344\223\002\034\"\032/v1/backupetcd/{namespace}'
  _LISTMODELASYSTEMSREQUEST._serialized_start=332
  _LISTMODELASYSTEMSREQUEST._serialized_end=534
  _LISTMODELASYSTEMSREQUEST_LABELSENTRY._serialized_start=489
  _LISTMODELASYSTEMSREQUEST_LABELSENTRY._serialized_end=534
  _LISTMODELASYSTEMSRESPONSE._serialized_start=536
  _LISTMODELASYSTEMSRESPONSE._serialized_end=659
  _MODELASYSTEMRESPONSE._serialized_start=661
  _MODELASYSTEMRESPONSE._serialized_end=683
  _CREATEMODELASYSTEMREQUEST._serialized_start=686
  _CREATEMODELASYSTEMREQUEST._serialized_end=822
  _CREATEMODELASYSTEMRESPONSE._serialized_start=824
  _CREATEMODELASYSTEMRESPONSE._serialized_end=852
  _UPDATEMODELASYSTEMREQUEST._serialized_start=855
  _UPDATEMODELASYSTEMREQUEST._serialized_end=1021
  _UPDATEMODELASYSTEMRESPONSE._serialized_start=1023
  _UPDATEMODELASYSTEMRESPONSE._serialized_end=1051
  _GETMODELASYSTEMREQUEST._serialized_start=1053
  _GETMODELASYSTEMREQUEST._serialized_end=1110
  _GETMODELASYSTEMRESPONSE._serialized_start=1113
  _GETMODELASYSTEMRESPONSE._serialized_end=1243
  _GETMODELASYSTEMNAMESPACESREQUEST._serialized_start=1245
  _GETMODELASYSTEMNAMESPACESREQUEST._serialized_end=1312
  _GETMODELASYSTEMNAMESPACESRESPONSE._serialized_start=1314
  _GETMODELASYSTEMNAMESPACESRESPONSE._serialized_end=1434
  _DELETEMODELASYSTEMREQUEST._serialized_start=1436
  _DELETEMODELASYSTEMREQUEST._serialized_end=1496
  _DELETEMODELASYSTEMRESPONSE._serialized_start=1498
  _DELETEMODELASYSTEMRESPONSE._serialized_end=1526
  _MODELASYSTEMCREATERESPONSE._serialized_start=1528
  _MODELASYSTEMCREATERESPONSE._serialized_end=1556
  _LOGOUTRESPONSE._serialized_start=1558
  _LOGOUTRESPONSE._serialized_end=1574
  _RESETPASSWORDRESPONSE._serialized_start=1576
  _RESETPASSWORDRESPONSE._serialized_end=1599
  _MODELASYSTEMGETBYNAMEREQUEST._serialized_start=1601
  _MODELASYSTEMGETBYNAMEREQUEST._serialized_end=1664
  _MODELASYSTEMLOGOUTREQUEST._serialized_start=1666
  _MODELASYSTEMLOGOUTREQUEST._serialized_end=1708
  _DOWNLOADLOGFILEREQUEST._serialized_start=1710
  _DOWNLOADLOGFILEREQUEST._serialized_end=1783
  _DOWNLOADLOGFILERESPONSE._serialized_start=1785
  _DOWNLOADLOGFILERESPONSE._serialized_end=1826
  _BACKUPDATABASEREQUEST._serialized_start=1828
  _BACKUPDATABASEREQUEST._serialized_end=1900
  _BACKUPDATABASERESPONSE._serialized_start=1902
  _BACKUPDATABASERESPONSE._serialized_end=1940
  _BACKUPETCDREQUEST._serialized_start=1942
  _BACKUPETCDREQUEST._serialized_end=2010
  _BACKUPETCDRESPONSE._serialized_start=2012
  _BACKUPETCDRESPONSE._serialized_end=2046
  _MODELASYSTEMSERVICE._serialized_start=2049
  _MODELASYSTEMSERVICE._serialized_end=3891
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.labelingpipelinerun.v1 import labelingpipelinerun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2


class LabelingPipelineRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListLabelingPipelineRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService/ListLabelingPipelineRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.ListLabelingPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.ListLabelingPipelineRunResponse.FromString,
                )
        self.CreateLabelingPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService/CreateLabelingPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.CreateLabelingPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.CreateLabelingPipelineRunResponse.FromString,
                )
        self.GetLabelingPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService/GetLabelingPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.GetLabelingPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.GetLabelingPipelineRunResponse.FromString,
                )
        self.UpdateLabelingPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService/UpdateLabelingPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.UpdateLabelingPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.UpdateLabelingPipelineRunResponse.FromString,
                )
        self.DeleteLabelingPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService/DeleteLabelingPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.DeleteLabelingPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.DeleteLabelingPipelineRunResponse.FromString,
                )


class LabelingPipelineRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListLabelingPipelineRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateLabelingPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLabelingPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateLabelingPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteLabelingPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LabelingPipelineRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListLabelingPipelineRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLabelingPipelineRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.ListLabelingPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.ListLabelingPipelineRunResponse.SerializeToString,
            ),
            'CreateLabelingPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateLabelingPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.CreateLabelingPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.CreateLabelingPipelineRunResponse.SerializeToString,
            ),
            'GetLabelingPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLabelingPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.GetLabelingPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.GetLabelingPipelineRunResponse.SerializeToString,
            ),
            'UpdateLabelingPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateLabelingPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.UpdateLabelingPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.UpdateLabelingPipelineRunResponse.SerializeToString,
            ),
            'DeleteLabelingPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteLabelingPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.DeleteLabelingPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.DeleteLabelingPipelineRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LabelingPipelineRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListLabelingPipelineRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService/ListLabelingPipelineRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.ListLabelingPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.ListLabelingPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateLabelingPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService/CreateLabelingPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.CreateLabelingPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.CreateLabelingPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLabelingPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService/GetLabelingPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.GetLabelingPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.GetLabelingPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateLabelingPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService/UpdateLabelingPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.UpdateLabelingPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.UpdateLabelingPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteLabelingPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService/DeleteLabelingPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.DeleteLabelingPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipelinerun_dot_v1_dot_labelingpipelinerun__pb2.DeleteLabelingPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/virtualvolume/v1/virtualvolume.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKgithub.com/metaprov/modelaapi/services/virtualvolume/v1/virtualvolume.proto\x12\x37github.com.metaprov.modelaapi.services.virtualvolume.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xcd\x01\n\x19ListVirtualVolumesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12n\n\x06labels\x18\x03 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x01\n\x1aListVirtualVolumesResponse\x12`\n\x0evirtualvolumes\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolumeList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x17\n\x15VirtualVolumeResponse\"y\n\x1a\x43reateVirtualVolumeRequest\x12[\n\rvirtualvolume\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"\x1d\n\x1b\x43reateVirtualVolumeResponse\"\xa9\x01\n\x1aUpdateVirtualVolumeRequest\x12[\n\rvirtualvolume\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1d\n\x1bUpdateVirtualVolumeResponse\":\n\x17GetVirtualVolumeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x85\x01\n\x18GetVirtualVolumeResponse\x12[\n\rvirtualvolume\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteVirtualVolumeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteVirtualVolumeResponse2\xde\t\n\x14VirtualVolumeService\x12\xe5\x01\n\x12ListVirtualVolumes\x12R.github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest\x1aS.github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/virtualvolumes/{namespace}\x12\xdf\x01\n\x13\x43reateVirtualVolume\x12S.github.com.metaprov.modelaapi.services.virtualvolume.v1.CreateVirtualVolumeRequest\x1aT.github.com.metaprov.modelaapi.services.virtualvolume.v1.CreateVirtualVolumeResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/virtualvolumes:\x01*\x12\xe6\x01\n\x10GetVirtualVolume\x12P.github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeRequest\x1aQ.github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/v1/virtualvolumes/{namespace}/{name}\x12\xa0\x02\n\x13UpdateVirtualVolume\x12S.github.com.metaprov.modelaapi.services.virtualvolume.v1.UpdateVirtualVolumeRequest\x1aT.github.com.metaprov.modelaapi.services.virtualvolume.v1.UpdateVirtualVolumeResponse\"^\x82\xd3\xe4\x93\x02X\x1aS/v1/virtualvolumes/{virtualvolume.metadata.namespace}/{virtualvolume.metadata.name}:\x01*\x12\xef\x01\n\x13\x44\x65leteVirtualVolume\x12S.github.com.metaprov.modelaapi.services.virtualvolume.v1.DeleteVirtualVolumeRequest\x1aT.github.com.metaprov.modelaapi.services.virtualvolume.v1.DeleteVirtualVolumeResponse\"-\x82\xd3\xe4\x93\x02\'*%/v1/virtualvolumes/{namespace}/{name}B9Z7github.com/metaprov/modelaapi/services/virtualvolume/v1b\x06proto3')



_LISTVIRTUALVOLUMESREQUEST = DESCRIPTOR.message_types_by_name['ListVirtualVolumesRequest']
_LISTVIRTUALVOLUMESREQUEST_LABELSENTRY = _LISTVIRTUALVOLUMESREQUEST.nested_types_by_name['LabelsEntry']
_LISTVIRTUALVOLUMESRESPONSE = DESCRIPTOR.message_types_by_name['ListVirtualVolumesResponse']
_VIRTUALVOLUMERESPONSE = DESCRIPTOR.message_types_by_name['VirtualVolumeResponse']
_CREATEVIRTUALVOLUMEREQUEST = DESCRIPTOR.message_types_by_name['CreateVirtualVolumeRequest']
_CREATEVIRTUALVOLUMERESPONSE = DESCRIPTOR.message_types_by_name['CreateVirtualVolumeResponse']
_UPDATEVIRTUALVOLUMEREQUEST = DESCRIPTOR.message_types_by_name['UpdateVirtualVolumeRequest']
_UPDATEVIRTUALVOLUMERESPONSE = DESCRIPTOR.message_types_by_name['UpdateVirtualVolumeResponse']
_GETVIRTUALVOLUMEREQUEST = DESCRIPTOR.message_types_by_name['GetVirtualVolumeRequest']
_GETVIRTUALVOLUMERESPONSE = DESCRIPTOR.message_types_by_name['GetVirtualVolumeResponse']
_DELETEVIRTUALVOLUMEREQUEST = DESCRIPTOR.message_types_by_name['DeleteVirtualVolumeRequest']
_DELETEVIRTUALVOLUMERESPONSE = DESCRIPTOR.message_types_by_name['DeleteVirtualVolumeResponse']
ListVirtualVolumesRequest = _reflection.GeneratedProtocolMessageType('ListVirtualVolumesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTVIRTUALVOLUMESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTVIRTUALVOLUMESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest)
  })
_sym_db.RegisterMessage(ListVirtualVolumesRequest)
_sym_db.RegisterMessage(ListVirtualVolumesRequest.LabelsEntry)

ListVirtualVolumesResponse = _reflection.GeneratedProtocolMessageType('ListVirtualVolumesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALVOLUMESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesResponse)
  })
_sym_db.RegisterMessage(ListVirtualVolumesResponse)

VirtualVolumeResponse = _reflection.GeneratedProtocolMessageType('VirtualVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALVOLUMERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeResponse)
  })
_sym_db.RegisterMessage(VirtualVolumeResponse)

CreateVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.CreateVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(CreateVirtualVolumeRequest)

CreateVirtualVolumeResponse = _reflection.GeneratedProtocolMessageType('CreateVirtualVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALVOLUMERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.CreateVirtualVolumeResponse)
  })
_sym_db.RegisterMessage(CreateVirtualVolumeResponse)

UpdateVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.UpdateVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualVolumeRequest)

UpdateVirtualVolumeResponse = _reflection.GeneratedProtocolMessageType('UpdateVirtualVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALVOLUMERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.UpdateVirtualVolumeResponse)
  })
_sym_db.RegisterMessage(UpdateVirtualVolumeResponse)

GetVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('GetVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(GetVirtualVolumeRequest)

GetVirtualVolumeResponse = _reflection.GeneratedProtocolMessageType('GetVirtualVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALVOLUMERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeResponse)
  })
_sym_db.RegisterMessage(GetVirtualVolumeResponse)

DeleteVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.DeleteVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualVolumeRequest)

DeleteVirtualVolumeResponse = _reflection.GeneratedProtocolMessageType('DeleteVirtualVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALVOLUMERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.DeleteVirtualVolumeResponse)
  })
_sym_db.RegisterMessage(DeleteVirtualVolumeResponse)

_VIRTUALVOLUMESERVICE = DESCRIPTOR.services_by_name['VirtualVolumeService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/metaprov/modelaapi/services/virtualvolume/v1'
  _LISTVIRTUALVOLUMESREQUEST_LABELSENTRY._options = None
  _LISTVIRTUALVOLUMESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _VIRTUALVOLUMESERVICE.methods_by_name['ListVirtualVolumes']._options = None
  _VIRTUALVOLUMESERVICE.methods_by_name['ListVirtualVolumes']._serialized_options = b'\202\323\344\223\002 \022\036/v1/virtualvolumes/{namespace}'
  _VIRTUALVOLUMESERVICE.methods_by_name['CreateVirtualVolume']._options = None
  _VIRTUALVOLUMESERVICE.methods_by_name['CreateVirtualVolume']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/virtualvolumes:\001*'
  _VIRTUALVOLUMESERVICE.methods_by_name['GetVirtualVolume']._options = None
  _VIRTUALVOLUMESERVICE.methods_by_name['GetVirtualVolume']._serialized_options = b'\202\323\344\223\002\'\022%/v1/virtualvolumes/{namespace}/{name}'
  _VIRTUALVOLUMESERVICE.methods_by_name['UpdateVirtualVolume']._options = None
  _VIRTUALVOLUMESERVICE.methods_by_name['UpdateVirtualVolume']._serialized_options = b'\202\323\344\223\002X\032S/v1/virtualvolumes/{virtualvolume.metadata.namespace}/{virtualvolume.metadata.name}:\001*'
  _VIRTUALVOLUMESERVICE.methods_by_name['DeleteVirtualVolume']._options = None
  _VIRTUALVOLUMESERVICE.methods_by_name['DeleteVirtualVolume']._serialized_options = b'\202\323\344\223\002\'*%/v1/virtualvolumes/{namespace}/{name}'
  _LISTVIRTUALVOLUMESREQUEST._serialized_start=335
  _LISTVIRTUALVOLUMESREQUEST._serialized_end=540
  _LISTVIRTUALVOLUMESREQUEST_LABELSENTRY._serialized_start=495
  _LISTVIRTUALVOLUMESREQUEST_LABELSENTRY._serialized_end=540
  _LISTVIRTUALVOLUMESRESPONSE._serialized_start=543
  _LISTVIRTUALVOLUMESRESPONSE._serialized_end=694
  _VIRTUALVOLUMERESPONSE._serialized_start=696
  _VIRTUALVOLUMERESPONSE._serialized_end=719
  _CREATEVIRTUALVOLUMEREQUEST._serialized_start=721
  _CREATEVIRTUALVOLUMEREQUEST._serialized_end=842
  _CREATEVIRTUALVOLUMERESPONSE._serialized_start=844
  _CREATEVIRTUALVOLUMERESPONSE._serialized_end=873
  _UPDATEVIRTUALVOLUMEREQUEST._serialized_start=876
  _UPDATEVIRTUALVOLUMEREQUEST._serialized_end=1045
  _UPDATEVIRTUALVOLUMERESPONSE._serialized_start=1047
  _UPDATEVIRTUALVOLUMERESPONSE._serialized_end=1076
  _GETVIRTUALVOLUMEREQUEST._serialized_start=1078
  _GETVIRTUALVOLUMEREQUEST._serialized_end=1136
  _GETVIRTUALVOLUMERESPONSE._serialized_start=1139
  _GETVIRTUALVOLUMERESPONSE._serialized_end=1272
  _DELETEVIRTUALVOLUMEREQUEST._serialized_start=1274
  _DELETEVIRTUALVOLUMEREQUEST._serialized_end=1335
  _DELETEVIRTUALVOLUMERESPONSE._serialized_start=1337
  _DELETEVIRTUALVOLUMERESPONSE._serialized_end=1366
  _VIRTUALVOLUMESERVICE._serialized_start=1369
  _VIRTUALVOLUMESERVICE._serialized_end=2615
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.userroleclass.v1 import userroleclass_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2


class UserRoleClassServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListUserRoleClasses = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/ListUserRoleClasses',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.ListUserRoleClassesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.ListUserRoleClassesResponse.FromString,
                )
        self.CreateUserRoleClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/CreateUserRoleClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.CreateUserRoleClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.CreateUserRoleClassResponse.FromString,
                )
        self.GetUserRoleClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/GetUserRoleClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.GetUserRoleClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.GetUserRoleClassResponse.FromString,
                )
        self.UpdateUserRoleClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/UpdateUserRoleClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.UpdateUserRoleClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.UpdateUserRoleClassResponse.FromString,
                )
        self.DeleteUserRoleClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/DeleteUserRoleClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.DeleteUserRoleClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.DeleteUserRoleClassResponse.FromString,
                )


class UserRoleClassServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListUserRoleClasses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUserRoleClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserRoleClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserRoleClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserRoleClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserRoleClassServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListUserRoleClasses': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserRoleClasses,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.ListUserRoleClassesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.ListUserRoleClassesResponse.SerializeToString,
            ),
            'CreateUserRoleClass': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUserRoleClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.CreateUserRoleClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.CreateUserRoleClassResponse.SerializeToString,
            ),
            'GetUserRoleClass': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserRoleClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.GetUserRoleClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.GetUserRoleClassResponse.SerializeToString,
            ),
            'UpdateUserRoleClass': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserRoleClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.UpdateUserRoleClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.UpdateUserRoleClassResponse.SerializeToString,
            ),
            'DeleteUserRoleClass': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserRoleClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.DeleteUserRoleClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.DeleteUserRoleClassResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserRoleClassService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListUserRoleClasses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/ListUserRoleClasses',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.ListUserRoleClassesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.ListUserRoleClassesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUserRoleClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/CreateUserRoleClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.CreateUserRoleClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.CreateUserRoleClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserRoleClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/GetUserRoleClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.GetUserRoleClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.GetUserRoleClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserRoleClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/UpdateUserRoleClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.UpdateUserRoleClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.UpdateUserRoleClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUserRoleClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/DeleteUserRoleClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.DeleteUserRoleClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.DeleteUserRoleClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.featureset.v1 import featureset_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2


class FeaturesetServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListFeaturesets = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService/ListFeaturesets',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.ListFeaturesetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.ListFeaturesetResponse.FromString,
                )
        self.CreateFeatureset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService/CreateFeatureset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.CreateFeaturesetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.CreateFeaturesetResponse.FromString,
                )
        self.GetFeatureset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService/GetFeatureset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.GetFeaturesetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.GetFeaturesetResponse.FromString,
                )
        self.UpdateFeatureset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService/UpdateFeatureset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.UpdateFeaturesetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.UpdateFeaturesetResponse.FromString,
                )
        self.DeleteFeatureset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService/DeleteFeatureset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.DeleteFeaturesetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.DeleteFeaturesetResponse.FromString,
                )


class FeaturesetServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListFeaturesets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeatureset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeaturesetServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListFeaturesets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeaturesets,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.ListFeaturesetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.ListFeaturesetResponse.SerializeToString,
            ),
            'CreateFeatureset': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeatureset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.CreateFeaturesetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.CreateFeaturesetResponse.SerializeToString,
            ),
            'GetFeatureset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.GetFeaturesetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.GetFeaturesetResponse.SerializeToString,
            ),
            'UpdateFeatureset': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.UpdateFeaturesetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.UpdateFeaturesetResponse.SerializeToString,
            ),
            'DeleteFeatureset': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.DeleteFeaturesetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.DeleteFeaturesetResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeaturesetService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListFeaturesets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService/ListFeaturesets',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.ListFeaturesetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.ListFeaturesetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeatureset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService/CreateFeatureset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.CreateFeaturesetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.CreateFeaturesetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService/GetFeatureset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.GetFeaturesetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.GetFeaturesetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService/UpdateFeatureset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.UpdateFeaturesetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.UpdateFeaturesetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService/DeleteFeatureset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.DeleteFeaturesetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featureset_dot_v1_dot_featureset__pb2.DeleteFeaturesetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.review.v1 import review_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2


class ReviewServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListReviews = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.review.v1.ReviewService/ListReviews',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.ListReviewRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.ListReviewResponse.FromString,
                )
        self.CreateReview = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.review.v1.ReviewService/CreateReview',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.CreateReviewRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.CreateReviewResponse.FromString,
                )
        self.GetReview = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.review.v1.ReviewService/GetReview',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.GetReviewRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.GetReviewResponse.FromString,
                )
        self.UpdateReview = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.review.v1.ReviewService/UpdateReview',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.UpdateReviewRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.UpdateReviewResponse.FromString,
                )
        self.DeleteReview = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.review.v1.ReviewService/DeleteReview',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.DeleteReviewRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.DeleteReviewResponse.FromString,
                )


class ReviewServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListReviews(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteReview(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReviewServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListReviews': grpc.unary_unary_rpc_method_handler(
                    servicer.ListReviews,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.ListReviewRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.ListReviewResponse.SerializeToString,
            ),
            'CreateReview': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateReview,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.CreateReviewRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.CreateReviewResponse.SerializeToString,
            ),
            'GetReview': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReview,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.GetReviewRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.GetReviewResponse.SerializeToString,
            ),
            'UpdateReview': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateReview,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.UpdateReviewRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.UpdateReviewResponse.SerializeToString,
            ),
            'DeleteReview': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteReview,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.DeleteReviewRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.DeleteReviewResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.review.v1.ReviewService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ReviewService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListReviews(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.review.v1.ReviewService/ListReviews',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.ListReviewRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.ListReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.review.v1.ReviewService/CreateReview',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.CreateReviewRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.CreateReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.review.v1.ReviewService/GetReview',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.GetReviewRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.GetReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.review.v1.ReviewService/UpdateReview',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.UpdateReviewRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.UpdateReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteReview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.review.v1.ReviewService/DeleteReview',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.DeleteReviewRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_review_dot_v1_dot_review__pb2.DeleteReviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
